# Hashchain  

## Introduction
`hashchain` is a Python package developed to join the ease of use of Python with the security of blockchain to certify that your important records haven't been tampered with. 

The core module creates a hash chain, attesting that no record can be tempered with, once saved. The blockchain module save a proof of your hashchain permanentely in the most secured way. Then, it's impossible to alter the haschain without causing a discrepancy with the blockchain.  

No need for third party certification anymore. No more single point of failure nor certification costs. 

## Disclaimer
The package is still 'work in progress' Do not use it before the official beta release. All the features are still subject to changes without any advertisement and can broke previously running scripts 


## Installation
This python package is available on PyPi package manager. I recommend installing it in a [virtual environment](https://virtualenv.pypa.io/en/latest/).  
1. Open a terminal and run the following command : `pip install hashchain`
2. Import the package in you script with `import hashchain`

This package is tested against Python 3.5.7 and 3.7.1 versions

## How to start using haschain? 
The documentation lives on [ReadTheDocs](https://hashchain.readthedocs.io/en/latest/)

I wrote an article on Medium to show a simple example of this package utilization: https://medium.com/@svandegar/certify-data-on-blockchain-with-python-and-no-prior-blockchain-experience-f09b7e3deb30


## Contribute
I would be happy to hear from you if you have any comments, suggestions or requests to share with me. 

## Changelog
### 1.0.0
Beta release
